@@ -36,10 +36,10 @@ import glob
 import shutil
 import time
 import contextlib
+import platform
 
-# TODO: Clean up finding executable on Windows.  Maybe automatically search for gs if
-# pdftoppm fails?  Current code doesn't seem to.  Note gs needs to be findable on PATH,
-# but it gets placed in C:\Program Files\gs\gs9.27\bin\gswin64c.exe (for example).
+WINDOWS_GS64_GLOB = r"C:\Program Files*\gs\gs*\bin\gswin64c.exe"
+WINDOWS_GS32_GLOB = r"C:\Program Files*\gs\gs*\bin\gswin32c.exe"
 
 temp_file_prefix = "pdfCropMarginsTmp_"     # prefixed to all temporary filenames
 temp_dir_prefix = "pdfCropMarginsTmpDir_"   # prefixed to all temporary dirnames
@@ -50,8 +50,6 @@ cygwin_full_path_prefix = "/cygdrive"
 ## Get info about the OS we're running on.
 ##
 
-import platform
-
 #  Get the version as a tuple of strings: (major, minor, patchlevel)
 python_version = platform.python_version_tuple() # sys.version_info works too
 
@@ -62,8 +60,6 @@ system_os = platform.system()
 if system_os[:6].lower() == "cygwin":
     system_os = "Cygwin"
 
-# TODO: Below line seems no longer necessary; the condition is not checked.
-# Either check again or update the man page.
 #system_os = "Windows" # Uncomment ONLY to test Windows on Linux with Wine.
 
 # Find the number of bits the OS supports.
@@ -114,14 +110,19 @@ def get_directory_location():
     from . import directory_locator
     return get_canonical_absolue_expanded_dirname(directory_locator.__file__)
 
+def get_expanded_path(path):
+    """Get the canonical form of the absolute path from a possibly relative path
+    (which may have symlinks, etc.)"""
+    return os.path.expandvars(os.path.expanduser(path))
+
 def get_canonical_absolute_expanded_path(path):
     """Get the canonical form of the absolute path from a possibly relative path
     (which may have symlinks, etc.)"""
     return os.path.normcase(
                os.path.normpath(
-                   os.path.realpath( # remove any symbolic links
-                       os.path.abspath( # may not be needed with realpath, to be safe
-                           os.path.expanduser(path)))))
+                   os.path.realpath( # Remove any symbolic links.
+                       os.path.abspath( # May not be needed with realpath; to be safe.
+                           get_expanded_path(path)))))
 
 def get_canonical_absolue_expanded_dirname(path):
     """Get the absolute directory name from a possibly relative path."""
@@ -142,22 +143,26 @@ def get_parent_directory(path):
         path = os.path.dirname(path)
     return os.path.abspath(os.path.join(path, os.path.pardir))
 
-def glob_if_windows_os(path, exact_num_args=False):
-    """Expands any globbing if `system_os` is Windows (DOS doesn't do it).  The
-    argument `exact_num_args` can be set to an integer to check for an exact
-    number of matching files.  Returns a list."""
-    if system_os != "Windows":
+def glob_pathname(path, exact_num_args=False, windows_only=False):
+    """Expands any globbing in `path` (Windows shells don't do it).
+
+    The `path` parameter should be a single pathname possibly containing glob
+    symbols. The argument `exact_num_args` can be set to an integer to check
+    for an exact number of matching files.  If `window_only` is true and
+    `system_os` is not Windows then a list containing `path` is returned
+    unmodified.
+
+    Returns a list of all the matching paths."""
+    if windows_only and system_os != "Windows":
         return [path]
     globbed = glob.glob(path)
-    if not globbed:
+    if not globbed: # Empty list of matching paths.
         print("\nWarning in pdfCropMargins: The wildcards in the path\n   "
-              + path + "\nfailed to expand.  Treating as literal.",
-              file=sys.stderr)
+              + path + "\nfailed to expand.  Treating as literal.", file=sys.stderr)
         globbed = [path]
     if exact_num_args and len(globbed) != exact_num_args:
         print("\nError in pdfCropMargins: The wildcards in the path\n   "
-              + path + "\nexpand to the wrong number of files.",
-              file=sys.stderr)
+              + path + "\nexpand to the wrong number of files.", file=sys.stderr)
         cleanup_and_exit(1)
     return globbed
 
@@ -299,9 +304,8 @@ def get_external_subprocess_output(command_list, print_output=False, indent_stri
         sys.stdout.flush()
     return output
 
-def call_external_subprocess(command_list,
-                       stdin_filename=None, stdout_filename=None, stderr_filename=None,
-                       env=None):
+def call_external_subprocess(command_list, stdin_filename=None, stdout_filename=None,
+                             stderr_filename=None, env=None):
     """Run the command and arguments in the command_list.  Will search the system
     PATH for commands to execute, but no shell is started.  Redirects any selected
     outputs to the given filename.  Waits for command completion."""
@@ -354,15 +358,14 @@ def init_and_test_gs_executable(exit_on_fail=False):
     # First try basic names against the PATH.
     gs_executable = find_and_test_executable(gs_executables, ["-dSAFER", "-v"], "Ghostscript")
 
-    # If that fails, on Windows or Cygwin look in the Program Files gs directory for it.
+    # If that fails, on Windows or Cygwin look in the 'Program Files' gs directory for it.
     if not gs_executable and (system_os == "Windows" or system_os == "Cygwin"):
-        # TODO maybe move these strings to top as module settable strings
-        gs64 = glob.glob(r"C:\Program Files*\gs\gs*\bin\gswin64c.exe")
+        gs64 = glob.glob(WINDOWS_GS64_GLOB)
         if gs64:
             gs64 = gs64[0] # just take the first one for now
         else:
             gs64 = ""
-        gs32 = glob.glob(r"C:\Program Files*\gs\gs*\bin\gswin32c.exe")
+        gs32 = glob.glob(WINDOWS_GS32_GLOB)
         if gs32:
             gs32 = gs32[0] # just take the first one for now
         else:
