@@ -281,7 +281,7 @@ def get_full_page_box_list_assigning_media_and_crop(input_doc, quiet=False,
         if args.verbose and not quiet:
             # want to display page num numbering from 1, so add one
             print("\t"+str(page_num+1), "  rot =",
-                  curr_page.rotationAngle, "\t", full_page_box)
+                  curr_page.rotationAngle, "\t", list(full_page_box))
 
         # Convert the `RectangleObject` to floats in an ordinary list and append.
         ordinary_box = [float(b) for b in full_page_box]
@@ -406,19 +406,30 @@ def calculate_crop_list(full_page_box_list, bounding_box_list, angle_list,
     # percent>100.  They are added (lb) or subtracted (tr) as appropriate.
 
     delta_list = []
-    for p_num, t_box, f_box in zip(list(range(len(full_page_box_list))),
-                                               bounding_box_list, full_page_box_list):
-        deltas = [abs(t_box[m_val] - f_box[m_val]) for m_val in range(4)]
-        adj_deltas = [deltas[m_val] * (100.0-rotated_percent_retain[p_num][m_val]) / 100.0
-                     for m_val in range(4)]
-        adj_deltas = [adj_deltas[m_val] + rotated_absolute_offset[p_num][m_val] for m_val in range(4)]
+    for p_num, (b_box, f_box) in enumerate(zip(bounding_box_list, full_page_box_list)):
+        # Calculate margin percentages.
+        pct_fracs = [rotated_percent_retain[p_num][m_val] / 100.0 for m_val in range(4)]
+        deltas = [abs(b_box[m_val] - f_box[m_val]) for m_val in range(4)]
+        if not args.percentText:
+            adj_deltas = [deltas[m_val] * (1.0-pct_fracs[m_val]) for m_val in range(4)]
+        else:
+            text_size = (b_box[2]-b_box[0], b_box[3]-b_box[1], # Text size for each margin.
+                         b_box[2]-b_box[0], b_box[3]-b_box[1])
+            adj_deltas = [deltas[m_val] - text_size[m_val] * pct_fracs[m_val]
+                                                                 for m_val in range(4)]
+
+        # Calculate absolute offsets.
+        adj_deltas = [adj_deltas[m_val] + rotated_absolute_offset[p_num][m_val]
+                                                                    for m_val in range(4)]
         delta_list.append(adj_deltas)
 
     # Handle the '--uniform' options if one was selected.
     if args.uniformOrderPercent:
         percent_val = args.uniformOrderPercent[0]
-        if percent_val < 0.0: percent_val = 0.0
-        if percent_val > 100.0: percent_val = 100.0
+        if percent_val < 0.0:
+            percent_val = 0.0
+        if percent_val > 100.0:
+            percent_val = 100.0
         args.uniformOrderStat4 = [int(round(num_pages_to_crop * percent_val / 100.0))] * 4
 
     if args.uniform or args.uniformOrderStat4:
@@ -565,7 +576,7 @@ def set_cropped_metadata(input_doc, output_doc, metadata_info):
 
 def apply_crop_list(crop_list, input_doc, page_nums_to_crop,
                                           already_cropped_by_this_program):
-    """Apply the crop list to the pages of the input PdfFileReader object."""
+    """Apply the crop list to the pages of the input `PdfFileReader` object."""
 
     if args.restore and not already_cropped_by_this_program:
         print("\nWarning from pdfCropMargins: The Producer string indicates that"
@@ -581,7 +592,7 @@ def apply_crop_list(crop_list, input_doc, page_nums_to_crop,
             print("\nNew full page sizes after cropping, in PDF format (lbrt):")
 
     if args.writeCropDataToFile:
-        args.writeCropDataToFile = os.path.expanduser(args.writeCropDataToFile)
+        args.writeCropDataToFile = ex.get_expanded_path(args.writeCropDataToFile)
         f = open(args.writeCropDataToFile, "w")
 
     # Copy over each page, after modifying the appropriate PDF boxes.
@@ -623,9 +634,9 @@ def apply_crop_list(crop_list, input_doc, page_nums_to_crop,
         new_cropped_box = RectangleObject(crop_list[page_num])
 
         if args.verbose:
-            print("\t"+str(page_num+1)+"\t", new_cropped_box) # page numbering from 1
+            print("\t"+str(page_num+1)+"\t", list(new_cropped_box)) # page numbering from 1
         if args.writeCropDataToFile:
-            print("\t"+str(page_num+1)+"\t", new_cropped_box, file=f)
+            print("\t"+str(page_num+1)+"\t", list(new_cropped_box), file=f)
 
         if not args.boxesToSet:
             args.boxesToSet = ["m", "c"]
@@ -781,13 +792,9 @@ def setup_output_document(input_doc, tmp_input_doc, metadata_info,
 def process_command_line_arguments(parsed_args):
     """Perform an initial processing on the some of the command-line arguments.  This
     is called first, before any PDF processing is done."""
-    global args # This is global only to avoid passing it to essentially every function.
+    global args # This is global o nly to avoid passing it to essentially every function.
     args = parsed_args
 
-    if args.version:
-        print(__version__, end="")
-        ex.cleanup_and_exit(0)
-
     if args.verbose:
         print("\nProcessing the PDF with pdfCropMargins (version", __version__+")...")
         print("Python version:", ex.python_version)
@@ -804,8 +811,9 @@ def process_command_line_arguments(parsed_args):
     # Process input and output filenames.
     #
 
-    input_doc_fname = ex.glob_if_windows_os(args.pdf_input_doc[0], exact_num_args=1)[0]
-    input_doc_fname = os.path.expanduser(input_doc_fname)
+    input_doc_fname = args.pdf_input_doc[0]
+    input_doc_fname = ex.get_expanded_path(input_doc_fname) # Expand vars and user.
+    input_doc_fname = ex.glob_pathname(input_doc_fname, exact_num_args=1)[0]
     if not input_doc_fname.endswith((".pdf",".PDF")):
         print("\nWarning in pdfCropMargins: The file extension is neither '.pdf'"
               "\nnor '.PDF'; continuing anyway.", file=sys.stderr)
@@ -822,8 +830,9 @@ def process_command_line_arguments(parsed_args):
             print("\nUsing the default-generated output filename.")
         output_doc_fname = generate_default_filename(input_doc_fname)
     else:
-        output_doc_fname = ex.glob_if_windows_os(args.outfile[0], exact_num_args=1)[0]
-    output_doc_fname = os.path.expanduser(output_doc_fname)
+        output_doc_fname = args.outfile[0]
+
+    output_doc_fname = ex.get_expanded_path(output_doc_fname)
     if args.verbose:
         print("\nThe output document's filename will be:\n   ", output_doc_fname)
 
@@ -1031,14 +1040,15 @@ def process_pdf_file(input_doc_fname, fixed_input_doc_fname, output_doc_fname,
         tmp_input_doc = PdfFileReader(fixed_input_doc_file_object)
     except (KeyboardInterrupt, EOFError):
         raise
-    except: # Can raise various exceptions, just catch the rest here.
-
-        print("\nError in pdfCropMargins: The pyPdf module failed in an attempt"
-              "\nto read the input file.  Is the file a PDF file?  If so then it"
-              "\nmay be corrupted.  If you have Ghostscript installed you can"
-              "\nattempt to fix it by using the pdfCropMargins option '--gsFix'"
+    except Exception as e: # PyPDF2 can raise various, catch the rest here.
+        print("\nError in pdfCropMargins: The PyPDF2 module failed in an"
+              "\nattempt to read this input file:\n   {}\n"
+              "\nIs the file a PDF file?  If so then it may be corrupted."
+              "\nIf you have Ghostscript installed you can attempt to fix"
+              "\nthe document by using the pdfCropMargins option '--gsFix'"
               "\n(assuming you are not using that option already).  That option"
-              "\ncan also convert some PostScript files to a readable format.",
+              "\ncan also convert some PostScript files to a readable format."
+              "\n\nThe error message was:\n   {}".format(fixed_input_doc_fname, e),
               file=sys.stderr)
         ex.cleanup_and_exit(1)
 
@@ -1065,8 +1075,22 @@ def process_pdf_file(input_doc_fname, fixed_input_doc_fname, output_doc_fname,
     ## Print out some data and metadata in verbose mode.
     ##
 
+    try: # Note this is after decryption.
+        input_doc_num_pages = input_doc.getNumPages() # Can raise PdfReadError.
+    except PdfReadError as e:
+        print("\nError in pdfCropMargins: The PyPDF2 module failed in an"
+              "\nattempt to read this input file:\n   {}\n"
+              "\nIs the file a PDF file?  If so then it may be corrupted."
+              "\nIf you have Ghostscript installed you can attempt to fix"
+              "\nthe document by using the pdfCropMargins option '--gsFix'"
+              "\n(assuming you are not using that option already).  That option"
+              "\ncan also convert some PostScript files to a readable format."
+              "\n\nThe error message was:\n   {}".format(fixed_input_doc_fname, e),
+              file=sys.stderr)
+        ex.cleanup_and_exit(1)
+
     if args.verbose:
-        print("\nThe input document has %s pages." % input_doc.getNumPages())
+        print("\nThe input document has {} pages.".format(input_doc_num_pages))
 
     try: # This is needed because the call sometimes just raises an error.
         metadata_info = input_doc.getDocumentInfo()
@@ -1106,7 +1130,7 @@ def process_pdf_file(input_doc_fname, fixed_input_doc_fname, output_doc_fname,
     ## for any pages which were not selected.
     ##
 
-    all_page_nums = set(range(0, input_doc.getNumPages()))
+    all_page_nums = set(range(0, input_doc_num_pages))
     if args.pages:
         try:
             page_nums_to_crop = parse_page_range_specifiers(args.pages, all_page_nums)
@@ -1378,7 +1402,7 @@ def main_crop(argv_list=None):
                                            process_command_line_arguments(parsed_args))
 
     if args.gui:
-        from .gui import create_gui
+        from .gui import create_gui # Import here; tkinter might not be installed.
         if args.verbose:
             print("\nWaiting for the GUI...")
 
