@@ -55,6 +55,7 @@ from __future__ import print_function, division, absolute_import
 
 import argparse
 import sys
+from . import __version__ # Get the version number from the __init__.py file.
 
 DEFAULT_THRESHOLD_VALUE = 191
 
@@ -316,6 +317,16 @@ cmd_parser.add_argument("-p4", "-pppp", "--percentRetain4", nargs=4,
    left, bottom, right, and top margins, respectively.  The four arguments
    should be percent values.^^n""")
 
+cmd_parser.add_argument("-pt", "--percentText", action="store_true", help="""
+
+   Normally the percentage values passed to '--percentRetain' or
+   '--percentRetain4' define the percentage of existing margins to retain.
+   This flag alters the interpretation of those percent values.  The margins
+   are instead set to the given percentage of the text width or height.  The
+   left and right margins are set to a percentage of the bounding box width and
+   the bottom and top margins are set to a percentage of the bounding box
+   height.^^n""")
+
 cmd_parser.add_argument("-a", "--absoluteOffset", nargs=1, type=float,
                         metavar="BP", default=[0.0], help="""
 
@@ -776,10 +787,8 @@ cmd_parser.add_argument("-pdl", "--pdftoppmLocal", action="store_true", help="""
    This option is only available on Windows machines; it is ignored otherwise.
    By default the first pdftoppm executable found in the directories in the
    PATH environment variable is used.  On Windows the program will revert to
-   this option if PDF image-rendering is required and no system pdftoppm or
-   Ghostscript executable can be found.  The locally-packaged pdftoppm
-   executable is a few years old, but for page-cropping it only needs to get
-   the margins right.^^n""")
+   this option if PDF image-rendering is required, PyMuPDF is not installed,
+   and no system pdftoppm or Ghostscript executable can be found.^^n""")
 
 cmd_parser.add_argument("-gsp", "--ghostscriptPath", type=str, metavar="PATH",
                         default="", help="""
@@ -795,7 +804,8 @@ cmd_parser.add_argument("-ppp", "--pdftoppmPath", type=str, metavar="PATH",
    No globbing is done.  Useful when the program is in a nonstandard
    location.^^n""")
 
-cmd_parser.add_argument("--version", action="store_true", help="""
+cmd_parser.add_argument("--version", action="version",
+                        version="pdfCropMargins {}".format(__version__), help="""
 
    Return the pdfCropMargins version number and exit immediately.  All
    other options are ignored.^^n""")
