@@ -51,7 +51,7 @@ if has_mupdf:
         """Holds `pyMuPDF` document and PyMuPDF pages of the document for the GUI
         to display.  Has methods to get rendered images.  Note that the page numbering
         convention is from zero."""
-        def __init__(self, args=None):
+        def __init__(self, args):
             """Initialize an empty object.  The `args` parameter should be passed a
             parsed command-line argument object from argparse with the user-selected
             command-line options."""
@@ -70,11 +70,34 @@ if has_mupdf:
                 self.document = fitz.open(doc_fname)
             except RuntimeError:
                 print("\nError in pdfCropMargins: The PyMuPDF program could not read"
-                      " the document\n   '{}'\nin order to display it in the GUI.   If you have"
-                      " Ghostscript installed\nconsider running pdfCropMargins with the"
+                      " the document\n   '{}'\nin order to display it in the GUI.   If you"
+                      " have Ghostscript installed\nconsider running pdfCropMargins with the"
                       " '--gsFix' option to attempt to repair it."
                       .format(doc_fname), file=sys.stderr)
                 ex.cleanup_and_exit(1)
+
+            # Decrypt if necessary.
+            if self.document.isEncrypted:
+                if self.args.password:
+                    # Return code is positive for success, negative for failure. If positive,
+                    #   bit 0 set = no password required
+                    #   bit 1 set = user password authenticated
+                    #   bit 2 set = owner password authenticated
+                    authenticate_code = self.document.authenticate(self.args.password)
+                    if self.document.isEncrypted:
+                        print("\nError in pdfCropMargins: The document was not correctly "
+                              "decrypted by PyMuPDF using the password passed in.",
+                              file=sys.stderr)
+                        ex.cleanup_and_exit(1)
+                else: # Try an empty password.
+                    authenticate_code = self.document.authenticate("")
+                    if self.document.isEncrypted:
+                        print("\nError in pdfCropMargins: The document is encrypted "
+                              "and the empty password does not work.  Try passing in a "
+                              "password with the '--password' option.",
+                              file=sys.stderr)
+                        ex.cleanup_and_exit(1)
+
             self.num_pages = len(self.document)
             self.page_display_list_cache = [None] * self.num_pages
             self.page_crop_display_list_cache = [None] * self.num_pages
@@ -105,13 +128,14 @@ if has_mupdf:
             if cache:
                 page_crop_display_list = self.page_crop_display_list_cache[page_num]
                 if not page_crop_display_list:  # Create if not yet there.
-                    self.page_crop_display_list_cache[page_num] = self.document[page_num].getDisplayList()
+                    self.page_crop_display_list_cache[page_num] = self.document[
+                                                                  page_num].getDisplayList()
                     page_crop_display_list = self.page_crop_display_list_cache[page_num]
             else:
                 page_crop_display_list = self.document[page_num].getDisplayList()
 
             # https://github.com/pymupdf/PyMuPDF/issues/322 # Also info on opening in Pillow.
-            # TODO: Above page also lists faster way than getting ppm first.
+            # TODO: Above page also lists a faster way than getting ppm first.
 
             # Pillow Image: https://pillow.readthedocs.io/en/stable/reference/Image.html
             # Pillow modes: https://pillow.readthedocs.io/en/stable/handbook/concepts.html#concept-modes
@@ -134,21 +158,19 @@ if has_mupdf:
             image_ppm = pixmap.getImageData("ppm")  # Make PPM image from pixmap for tkinter.
             return image_ppm
 
-        def get_display_page(self, page_num, window_size, zoom=False, fit_screen=True):
+        def get_display_page(self, page_num, max_image_size, zoom=False,
+                             fit_screen=True, reset_cached=False):
             """Return a `tkinter.PhotoImage` or a PNG image for a document page number.
                 - The `page_num` argument is a 0-based page number.
                 - The `zoom` argument is the top-left of old clip rect, and one of -1, 0,
                   +1 for dim. x or y to indicate the arrow key pressed.
-                - The `max_size` argument is the (width, height) of available image area.
+                - The `max_image_size` argument is the (width, height) of available image area.
             """
-            # TODO: Newer demo version is cleaner, update to parts of it:
-            # https://github.com/PySimpleGUI/PySimpleGUI/blob/master/DemoPrograms/Demo_PDF_Viewer.py
-
             zoom_x = 1
             zoom_y = 1
             scale = fitz.Matrix(zoom_x, zoom_y)
 
-            page_display_list = self.page_display_list_cache[page_num]
+            page_display_list = self.page_display_list_cache[page_num] if not reset_cached else None
             if not page_display_list:  # Create if not yet there.
                 self.page_display_list_cache[page_num] = self.document[page_num].getDisplayList()
                 page_display_list = self.page_display_list_cache[page_num]
@@ -156,19 +178,19 @@ if has_mupdf:
             page_rect = page_display_list.rect  # The page rectangle.
             clip = page_rect
 
-            # Make sure that the image will fits the screen.
+            # Make sure that the image will fit the screen.
             zoom_0 = 1
-            if window_size:
-                zoom_0 = min(1, window_size[0] / page_rect.width, window_size[1] / page_rect.height)
+            if max_image_size: # TODO: this is currently a required param...
+                zoom_0 = min(1, max_image_size[0] / page_rect.width, max_image_size[1] / page_rect.height)
                 if zoom_0 == 1:
-                    zoom_0 = min(window_size[0] / page_rect.width, window_size[1] / page_rect.height)
+                    zoom_0 = min(max_image_size[0] / page_rect.width, max_image_size[1] / page_rect.height)
             mat_0 = fitz.Matrix(zoom_0, zoom_0)
 
             if zoom:
                 width2 = page_rect.width / 2
                 height2 = page_rect.height / 2
 
-                clip = page_rect * 0.5     # clip rect size is a quarter page
+                clip = page_rect * 0.5     # Clip rect size is a quarter page.
                 top_left = zoom[0]
                 top_left.x += zoom[1] * (width2 / 2)     # adjust top-left ...
                 top_left.x = max(0, top_left.x)          # according to ...
@@ -185,7 +207,9 @@ if has_mupdf:
             else:  # Show the total page.
                 pixmap = page_display_list.getPixmap(matrix=mat_0, alpha=False)
 
+            #image_png = pixmap.getPNGData()  # get the PNG image
+            image_height, image_width = pixmap.height, pixmap.width
             image_ppm = pixmap.getImageData("ppm")  # Make PPM image from pixmap for tkinter.
-
-            return image_ppm, clip.tl  # Return image, clip position.
+            image_tl = clip.tl # Clip position (top left).
+            return image_ppm, image_tl, image_height, image_width
 
